@@ -8,7 +8,6 @@ import time
 import pytz
 import pandas as pd
 import numpy as np
-import subprocess
 import threading
 from shutil import copy2
 from datetime import datetime
@@ -65,7 +64,6 @@ class AutoTraderBot():
         self.feed               = autotrader_attributes.feed
         self.data_file          = autotrader_attributes.data_file
         self.optimise_mode      = autotrader_attributes.optimise_mode
-        self.include_broker     = autotrader_attributes.include_broker
         self.check_data_alignment = autotrader_attributes.check_data_alignment
         self.allow_dancing_bears = autotrader_attributes.allow_dancing_bears
         self.use_stream         = autotrader_attributes.use_stream
@@ -114,44 +112,53 @@ class AutoTraderBot():
             
             # Check how many granularities were requested
             if len(interval.split(',')) > 1:
+                # MTF strategy
                 self.base_interval = interval.split(',')[0]
                 self.MTF_intervals = interval.split(',')[1:]
+                
+                # Initiate time_to_download dict
+                self.time_to_download = {}
+                for granularity in self.MTF_intervals:
+                    self.time_to_download[granularity] = datetime.now(tz=pytz.utc)
+                
             else:
+                # Single timeframe strategy
                 self.base_interval = interval
                 self.MTF_intervals = []
             
             # Start stream
             self._initiate_stream()
 
-        
+        # Multiple time-frame initialisation option
         if self.MTF_initialisation:
             # Only retrieve MTF_data once upon initialisation and store
             # instantiation MTF_data
             self.MTF_data = None
         
-        
+        # Data retrieval
         self.get_data = autodata.GetData(broker_config, self.allow_dancing_bears)
         data, quote_data, MTF_data = self._retrieve_data(instrument, self.feed)
         
+        # Data assignment
         if MTF_data is None:
             strat_data = data
         else:
             strat_data = MTF_data
         
-        if self.include_broker:
+        # Instantiate Strategy
+        include_broker = strategy_config['INCLUDE_BROKER'] if 'INCLUDE_BROKER' in strategy_config else False
+        if include_broker:
             my_strat = strategy(params, strat_data, instrument, self.broker, self.broker_utils)
         else:
             my_strat = strategy(params, strat_data, instrument)
             
-            
         # Assign strategy to local attributes
         self.strategy           = my_strat
         self.data               = data
         self.quote_data         = quote_data
         self.latest_orders      = []
         
-        
-        # Assign strategy attributes for development purposes
+        # Assign strategy attributes for tick-based strategy development
         if self.backtest_mode:
             self.strategy._backtesting = True
         if interval.split(',')[0] == 'tick':
@@ -230,7 +237,11 @@ class AutoTraderBot():
         '''
         Retrieves price data from AutoData.
         '''
-    
+        
+        # TODO - add time checks to download MTF data when streaming, to prevent
+        # downloading eg. 4 hour candles once every second. Instead, keep track 
+        # of time, and only download every eg. 4 hours
+        
         interval    = self.strategy_params['granularity']
         period      = self.strategy_params['period']
         price_data_path = os.path.join(self.home_dir, 'price_data')
@@ -381,15 +392,22 @@ class AutoTraderBot():
                     else:
                         # Download MTF data each update
                         for granularity in self.MTF_intervals:
-                            data = getattr(self.get_data, feed.lower())(instrument,
-                                                                        granularity = granularity,
-                                                                        count=period)
+                            if datetime.now(tz=pytz.utc) > self.time_to_download[granularity]:
+                                # Update MTF data
+                                data = getattr(self.get_data, feed.lower())(instrument,
+                                                                            granularity = granularity,
+                                                                            count=period)
                             
-                            if self.check_data_alignment:
-                                data = self._verify_data_alignment(data, instrument, feed, period, 
-                                                                   price_data_path)
-                            
-                            MTF_data[granularity] = data
+                                if self.check_data_alignment:
+                                    data = self._verify_data_alignment(data, instrument, feed, period, 
+                                                                       price_data_path)
+                                
+                                # Append to MTF_data
+                                MTF_data[granularity] = data
+                                
+                                # Update next time_to_download
+                                self.time_to_download[granularity] = self._next_candle_open(granularity)
+                                
                             
                 else:
                     # There is only one timeframe of data
@@ -593,6 +611,15 @@ class AutoTraderBot():
                 self._process_signal(order_signal_dict, i, self.data, 
                                     self.quote_data, self.instrument)
         
+        # TODO - implement the following, maybe
+        # else:
+        #     signal_type = order_signal_dict["signal_type"] if "signal_type" in order_signal_dict else None
+            
+        #     if signal_type == 'deployment':
+        #         # Strategy deployment signal
+        #         runfile = os.path.join(self.home_dir, order_signal_dict['runfile'])
+        #         os.system("nohup python3 {} &".format(runfile))
+        
         if int(self.verbosity) > 1:
             if len(self.latest_orders) > 0:
                 for order in self.latest_orders:
@@ -768,7 +795,18 @@ class AutoTraderBot():
             # Bot is trading
             self.broker.place_order(order_details)
             self.latest_orders.append(order_details)
-            
+    
+    def _next_candle_open(self, granularity):
+        '''
+        Returns the UTC datetime object corresponding to the open time of the 
+        next candle.
+        '''
+        
+        current_ts = datetime.now(tz=pytz.utc).timestamp()
+        granularity_in_seconds = self.broker_utils.interval_to_seconds(granularity)
+        next_candle_open_ts = granularity_in_seconds * np.ceil(current_ts / granularity_in_seconds)
+        
+        return datetime.fromtimestamp(next_candle_open_ts, tz=pytz.utc)
             
 
     def create_backtest_summary(self, balance, NAV, margin):
