@@ -45,7 +45,7 @@ class AutoTrader():
 
     Attributes
     ----------
-    Note: many of the following attributes are set from the methods of AutoTrader.
+    Note: many of the following attributes are set from the configure method of AutoTrader.
     
     feed : str 
         The data feed to be used (eg. Yahoo, Oanda).
@@ -59,14 +59,12 @@ class AutoTrader():
     home_dir : str 
         The project home directory.
     
-    include_broker : bool 
-        Set to True to assign broker to strategy attributes.
-    
     use_stream : bool 
         Set to True to use price stream as data feed.
     
     detach_bot : bool 
-        Set to True to spawn new thread for each bot deployed.
+        Set to True to spawn new thread for each bot deployed. Bots will then
+        continue to trade until a termination signal is recieved from the strategy.
     
     check_data_alignment : bool
         Verify time of latest candle in data recieved against current time.
@@ -94,7 +92,7 @@ class AutoTrader():
         Runs AutoTrader.
     
     configure(feed='yahoo', verbosity=1, notify=0, home_dir=None,
-              include_broker=False, use_stream=False, detach_bot=False,
+              use_stream=False, detach_bot=False,
               check_data_alignment=True, allow_dancing_bears=False,
               account_id=None, environment='demo', show_plot=False,
               MTF_initialisation=False):
@@ -123,14 +121,13 @@ class AutoTrader():
         self.show_plot      = False
         
         # Livetrade Parameters
-        self.detach_bot     = False         # TODO - make this a strategy config option
+        self.detach_bot     = False
         self.check_data_alignment = True
         self.allow_dancing_bears = False
         self.use_stream     = False
         self.MTF_initialisation = False
         self.stream_config  = None
         
-        # self.config         = None
         self.broker         = None
         self.broker_utils   = None
         self.environment    = 'demo'
@@ -140,7 +137,6 @@ class AutoTrader():
         self._uninitiated_strat_files = []
         self._uninitiated_strat_dicts = []
         self.feed           = 'yahoo'
-        self.include_broker = False         # TODO - make this a strategy config option
         self.bots_deployed  = []
         
         # Backtesting Parameters
@@ -254,7 +250,7 @@ class AutoTrader():
             broker_config['ACCOUNT_ID'] = self.account_id
         
         self._assign_broker(broker_config)
-        self.configure_emailing(global_config)
+        self._configure_emailing(global_config)
         
         if self.backtest_mode:
             starting_balance = self.broker.get_balance()
@@ -471,7 +467,7 @@ class AutoTrader():
     
     
     def configure(self, feed='yahoo', verbosity=1, notify=0, home_dir=None,
-                  include_broker=False, use_stream=False, detach_bot=False,
+                  use_stream=False, detach_bot=False,
                   check_data_alignment=True, allow_dancing_bears=False,
                   account_id=None, environment='demo', show_plot=False,
                   MTF_initialisation=False):
@@ -490,9 +486,6 @@ class AutoTrader():
                 
                 home_dir (str): the project home directory.
                 
-                include_broker (bool): set to True to assign broker to strategy
-                attributes.
-                
                 use_stream (bool): set to True to use price stream as data feed.
                 
                 detach_bot (bool): set to True to spawn new thread for each bot
@@ -518,7 +511,6 @@ class AutoTrader():
         self.verbosity = verbosity
         self.notify = notify
         self.home_dir = home_dir if home_dir is not None else os.getcwd()
-        self.include_broker = include_broker
         self.use_stream = use_stream
         self.detach_bot = detach_bot
         self.check_data_alignment = check_data_alignment
@@ -785,7 +777,7 @@ class AutoTrader():
         self.broker_utils = utils
     
     
-    def configure_emailing(self, global_config):
+    def _configure_emailing(self, global_config):
         '''
         Configure email settings.
         '''
